==> libreoffice-still-sdk-7.1.7-3-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/functions_d.js <==
var searchData=
[
  ['nativesql_0',['nativeSQL',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#aa7a4111bb7c9c56096db4b76b2fbeccf',1,'com::sun::star::sdbc::XConnection']]],
  ['newdocument_1',['newDocument',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XDocumentBuilder.html#a51e55c15fe62caec8a851d4fde5a939b',1,'com::sun::star::xml::dom::XDocumentBuilder']]],
  ['newinstance_2',['newInstance',['../interfacecom_1_1sun_1_1star_1_1xforms_1_1XFormsUIHelper1.html#abfbb3389137ca1a6491c591ebfee2d9c',1,'com::sun::star::xforms::XFormsUIHelper1']]],
  ['newlocale_3',['newLocale',['../interfacecom_1_1sun_1_1star_1_1resource_1_1XStringResourceManager.html#a93ec728e6f5874471f83593e35f20709',1,'com::sun::star::resource::XStringResourceManager']]],
  ['newmodel_4',['newModel',['../interfacecom_1_1sun_1_1star_1_1xforms_1_1XFormsUIHelper1.html#ad5bbd5d7300462dd319ed8fc5d5cadd0',1,'com::sun::star::xforms::XFormsUIHelper1']]],
  ['next_5',['next',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSet.html#a4d586217eb3cdd27c10608d4d5d36afb',1,'com::sun::star::sdbc::XResultSet']]],
  ['nextcharacters_6',['nextCharacters',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#a9940a7cbc82985f3df1b2e1ad1ffb079',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nextcharblock_7',['nextCharBlock',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#ac4b770c0aed309599bc01014b01d8ade',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nextcomponent_8',['nextComponent',['../interfacecom_1_1sun_1_1star_1_1container_1_1XComponentEnumeration.html#a464f9822afb30c92347f8868e724efc5',1,'com::sun::star::container::XComponentEnumeration']]],
  ['nexteffect_9',['nextEffect',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#afedc42797802ef07bf6084583f145f0b',1,'com::sun::star::presentation::XSlideShow']]],
  ['nextelement_10',['nextElement',['../interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotationEnumeration.html#a750455b8de91748b6d8099886473be84',1,'com::sun::star::office::XAnnotationEnumeration::nextElement()'],['../interfacecom_1_1sun_1_1star_1_1container_1_1XEnumeration.html#a61c8230f902446b133e7536fcfd11845',1,'com::sun::star::container::XEnumeration::nextElement()']]],
  ['nextscript_11',['nextScript',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#aaf05e276c5cc2997a64d77ebb2ae921a',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nexttypedescription_12',['nextTypeDescription',['../interfacecom_1_1sun_1_1star_1_1reflection_1_1XTypeDescriptionEnumeration.html#a31be4f2135004e04ae90f59e6b240e5c',1,'com::sun::star::reflection::XTypeDescriptionEnumeration']]],
  ['nextword_13',['nextWord',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#a62863e7bd383ca537443f88061773cce',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nodeedited_14',['nodeEdited',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeEditListener.html#aaed40b6b6170c5a25b4b3194709e9871',1,'com::sun::star::awt::tree::XTreeEditListener']]],
  ['nodeediting_15',['nodeEditing',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeEditListener.html#a2e6d6bc5fe78a6b2de2731c5ad96eb3d',1,'com::sun::star::awt::tree::XTreeEditListener']]],
  ['normalize_16',['normalize',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XNode.html#acd0de676568888d848beb97dcc53ae47',1,'com::sun::star::xml::dom::XNode']]],
  ['notationdecl_17',['notationDecl',['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XDTDHandler.html#a79e411a2032fc6ba6f810baf7bd9d541',1,'com::sun::star::xml::sax::XDTDHandler']]],
  ['notify_18',['notify',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XCallback.html#a642ac0aa5e92b14d76c1fd88f27fbd91',1,'com::sun::star::awt::XCallback::notify()'],['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XDynamicResultSetListener.html#af3a87c468a73c0366afb00cf19574c8b',1,'com::sun::star::ucb::XDynamicResultSetListener::notify()']]],
  ['notifyclosing_19',['notifyClosing',['../interfacecom_1_1sun_1_1star_1_1util_1_1XCloseListener.html#a5d5cf1744967aa666e39772d13dba0de',1,'com::sun::star::util::XCloseListener']]],
  ['notifyconfigurationchange_20',['notifyConfigurationChange',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationChangeListener.html#ad4c92e7424f59347aa323059b50d49d0',1,'com::sun::star::drawing::framework::XConfigurationChangeListener']]],
  ['notifycontextchangeevent_21',['notifyContextChangeEvent',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XContextChangeEventListener.html#acf6af4663a6e60229666e634b3e704cd',1,'com::sun::star::ui::XContextChangeEventListener']]],
  ['notifycontextmenuexecute_22',['notifyContextMenuExecute',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XContextMenuInterceptor.html#aa21cdccba804f6eb78d3951eb156ce29',1,'com::sun::star::ui::XContextMenuInterceptor']]],
  ['notifydocumentevent_23',['notifyDocumentEvent',['../interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentEventBroadcaster.html#acc6ecc6a67776809739f18310fc8cd8c',1,'com::sun::star::document::XDocumentEventBroadcaster']]],
  ['notifyevent_24',['notifyEvent',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleEventListener.html#a71db5f2878397c6c02ef409c709191be',1,'com::sun::star::accessibility::XAccessibleEventListener::notifyEvent()'],['../interfacecom_1_1sun_1_1star_1_1document_1_1XEventListener.html#afc3c859a9ee8009902b0a87274a47f35',1,'com::sun::star::document::XEventListener::notifyEvent()'],['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationControllerBroadcaster.html#a5b8d93c3fb21aa67316b5fea1fc93d79',1,'com::sun::star::drawing::framework::XConfigurationControllerBroadcaster::notifyEvent()']]],
  ['notifymailmergeevent_25',['notifyMailMergeEvent',['../interfacecom_1_1sun_1_1star_1_1text_1_1XMailMergeListener.html#afd67ae0077f976e6c9a505e250472f85',1,'com::sun::star::text::XMailMergeListener']]],
  ['notifymodifiedvalue_26',['notifyModifiedValue',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyControl.html#a0c535c7644f4b36ccda77846a34f530d',1,'com::sun::star::inspection::XPropertyControl']]],
  ['notifypasteevent_27',['notifyPasteEvent',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPasteListener.html#a95eba8cc24dbaefae2f99b9d8ecd2bf7',1,'com::sun::star::text::XPasteListener']]],
  ['notifypreviewcreation_28',['notifyPreviewCreation',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCacheListener.html#acd305876334e38d347b609f3807b0ec9',1,'com::sun::star::drawing::XSlidePreviewCacheListener']]],
  ['notifyshapeevent_29',['notifyShapeEvent',['../interfacecom_1_1sun_1_1star_1_1document_1_1XShapeEventListener.html#a618b1ed8187696c9e531c901b4c4a53b',1,'com::sun::star::document::XShapeEventListener']]],
  ['notifystoragechange_30',['notifyStorageChange',['../interfacecom_1_1sun_1_1star_1_1document_1_1XStorageChangeListener.html#ad006e8314fef6d21ab39d07411ebe907',1,'com::sun::star::document::XStorageChangeListener']]],
  ['notifytermination_31',['notifyTermination',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTerminateListener.html#a0706eb591601f0ab905dbc09e6b6699e',1,'com::sun::star::frame::XTerminateListener']]],
  ['notifyvbascriptevent_32',['notifyVBAScriptEvent',['../interfacecom_1_1sun_1_1star_1_1script_1_1vba_1_1XVBAScriptListener.html#a8102ad1483741fd69e1b7c2616a588f4',1,'com::sun::star::script::vba::XVBAScriptListener']]],
  ['nullplusnonnullisnull_33',['nullPlusNonNullIsNull',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a0bd08acbae007160cb7b545a63f26c10',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedatend_34',['nullsAreSortedAtEnd',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a949529017da964d23a9bbbd5f307523b',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedatstart_35',['nullsAreSortedAtStart',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#afe6224d12d287d561b6408fa1d8018fc',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedhigh_36',['nullsAreSortedHigh',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#aa29ce4154bfda07935c24b7a72e710dc',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedlow_37',['nullsAreSortedLow',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a37fac2ea5bc098e2770c369a2b11e9cc',1,'com::sun::star::sdbc::XDatabaseMetaData']]]
];

==> libreoffice-still-sdk-25.2.7-5-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/functions_d.js <==
var searchData=
[
  ['nativesql_0',['nativeSQL',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XConnection.html#aa7a4111bb7c9c56096db4b76b2fbeccf',1,'com::sun::star::sdbc::XConnection']]],
  ['newdocument_1',['newDocument',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XDocumentBuilder.html#a51e55c15fe62caec8a851d4fde5a939b',1,'com::sun::star::xml::dom::XDocumentBuilder']]],
  ['newinstance_2',['newInstance',['../interfacecom_1_1sun_1_1star_1_1xforms_1_1XFormsUIHelper1.html#abfbb3389137ca1a6491c591ebfee2d9c',1,'com::sun::star::xforms::XFormsUIHelper1']]],
  ['newlocale_3',['newLocale',['../interfacecom_1_1sun_1_1star_1_1resource_1_1XStringResourceManager.html#a93ec728e6f5874471f83593e35f20709',1,'com::sun::star::resource::XStringResourceManager']]],
  ['newmodel_4',['newModel',['../interfacecom_1_1sun_1_1star_1_1xforms_1_1XFormsUIHelper1.html#ad5bbd5d7300462dd319ed8fc5d5cadd0',1,'com::sun::star::xforms::XFormsUIHelper1']]],
  ['next_5',['next',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XResultSet.html#a4d586217eb3cdd27c10608d4d5d36afb',1,'com::sun::star::sdbc::XResultSet']]],
  ['nextcharacters_6',['nextCharacters',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#a9940a7cbc82985f3df1b2e1ad1ffb079',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nextcharblock_7',['nextCharBlock',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#ac4b770c0aed309599bc01014b01d8ade',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nextcomponent_8',['nextComponent',['../interfacecom_1_1sun_1_1star_1_1container_1_1XComponentEnumeration.html#a464f9822afb30c92347f8868e724efc5',1,'com::sun::star::container::XComponentEnumeration']]],
  ['nexteffect_9',['nextEffect',['../interfacecom_1_1sun_1_1star_1_1presentation_1_1XSlideShow.html#afedc42797802ef07bf6084583f145f0b',1,'com::sun::star::presentation::XSlideShow']]],
  ['nextelement_10',['nextElement',['../interfacecom_1_1sun_1_1star_1_1container_1_1XEnumeration.html#a61c8230f902446b133e7536fcfd11845',1,'com::sun::star::container::XEnumeration::nextElement()'],['../interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotationEnumeration.html#a750455b8de91748b6d8099886473be84',1,'com::sun::star::office::XAnnotationEnumeration::nextElement()']]],
  ['nextscript_11',['nextScript',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#aaf05e276c5cc2997a64d77ebb2ae921a',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nexttypedescription_12',['nextTypeDescription',['../interfacecom_1_1sun_1_1star_1_1reflection_1_1XTypeDescriptionEnumeration.html#a31be4f2135004e04ae90f59e6b240e5c',1,'com::sun::star::reflection::XTypeDescriptionEnumeration']]],
  ['nextword_13',['nextWord',['../interfacecom_1_1sun_1_1star_1_1i18n_1_1XBreakIterator.html#a62863e7bd383ca537443f88061773cce',1,'com::sun::star::i18n::XBreakIterator']]],
  ['nodeedited_14',['nodeEdited',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeEditListener.html#aaed40b6b6170c5a25b4b3194709e9871',1,'com::sun::star::awt::tree::XTreeEditListener']]],
  ['nodeediting_15',['nodeEditing',['../interfacecom_1_1sun_1_1star_1_1awt_1_1tree_1_1XTreeEditListener.html#a2e6d6bc5fe78a6b2de2731c5ad96eb3d',1,'com::sun::star::awt::tree::XTreeEditListener']]],
  ['normalize_16',['normalize',['../interfacecom_1_1sun_1_1star_1_1xml_1_1dom_1_1XNode.html#acd0de676568888d848beb97dcc53ae47',1,'com::sun::star::xml::dom::XNode']]],
  ['notationdecl_17',['notationDecl',['../interfacecom_1_1sun_1_1star_1_1xml_1_1sax_1_1XDTDHandler.html#a79e411a2032fc6ba6f810baf7bd9d541',1,'com::sun::star::xml::sax::XDTDHandler']]],
  ['notify_18',['notify',['../interfacecom_1_1sun_1_1star_1_1awt_1_1XCallback.html#a642ac0aa5e92b14d76c1fd88f27fbd91',1,'com::sun::star::awt::XCallback::notify()'],['../interfacecom_1_1sun_1_1star_1_1ucb_1_1XDynamicResultSetListener.html#af3a87c468a73c0366afb00cf19574c8b',1,'com::sun::star::ucb::XDynamicResultSetListener::notify()']]],
  ['notifyclosing_19',['notifyClosing',['../interfacecom_1_1sun_1_1star_1_1util_1_1XCloseListener.html#a5d5cf1744967aa666e39772d13dba0de',1,'com::sun::star::util::XCloseListener']]],
  ['notifyconfigurationchange_20',['notifyConfigurationChange',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationChangeListener.html#ad4c92e7424f59347aa323059b50d49d0',1,'com::sun::star::drawing::framework::XConfigurationChangeListener']]],
  ['notifycontextchangeevent_21',['notifyContextChangeEvent',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XContextChangeEventListener.html#acf6af4663a6e60229666e634b3e704cd',1,'com::sun::star::ui::XContextChangeEventListener']]],
  ['notifycontextmenuexecute_22',['notifyContextMenuExecute',['../interfacecom_1_1sun_1_1star_1_1ui_1_1XContextMenuInterceptor.html#aa21cdccba804f6eb78d3951eb156ce29',1,'com::sun::star::ui::XContextMenuInterceptor']]],
  ['notifydocumentevent_23',['notifyDocumentEvent',['../interfacecom_1_1sun_1_1star_1_1document_1_1XDocumentEventBroadcaster.html#acc6ecc6a67776809739f18310fc8cd8c',1,'com::sun::star::document::XDocumentEventBroadcaster']]],
  ['notifyevent_24',['notifyEvent',['../interfacecom_1_1sun_1_1star_1_1accessibility_1_1XAccessibleEventListener.html#a71db5f2878397c6c02ef409c709191be',1,'com::sun::star::accessibility::XAccessibleEventListener::notifyEvent()'],['../interfacecom_1_1sun_1_1star_1_1document_1_1XEventListener.html#afc3c859a9ee8009902b0a87274a47f35',1,'com::sun::star::document::XEventListener::notifyEvent()'],['../interfacecom_1_1sun_1_1star_1_1drawing_1_1framework_1_1XConfigurationControllerBroadcaster.html#a5b8d93c3fb21aa67316b5fea1fc93d79',1,'com::sun::star::drawing::framework::XConfigurationControllerBroadcaster::notifyEvent()']]],
  ['notifymailmergeevent_25',['notifyMailMergeEvent',['../interfacecom_1_1sun_1_1star_1_1text_1_1XMailMergeListener.html#afd67ae0077f976e6c9a505e250472f85',1,'com::sun::star::text::XMailMergeListener']]],
  ['notifymodifiedvalue_26',['notifyModifiedValue',['../interfacecom_1_1sun_1_1star_1_1inspection_1_1XPropertyControl.html#a0c535c7644f4b36ccda77846a34f530d',1,'com::sun::star::inspection::XPropertyControl']]],
  ['notifypasteevent_27',['notifyPasteEvent',['../interfacecom_1_1sun_1_1star_1_1text_1_1XPasteListener.html#a95eba8cc24dbaefae2f99b9d8ecd2bf7',1,'com::sun::star::text::XPasteListener']]],
  ['notifypreviewcreation_28',['notifyPreviewCreation',['../interfacecom_1_1sun_1_1star_1_1drawing_1_1XSlidePreviewCacheListener.html#acd305876334e38d347b609f3807b0ec9',1,'com::sun::star::drawing::XSlidePreviewCacheListener']]],
  ['notifyshapeevent_29',['notifyShapeEvent',['../interfacecom_1_1sun_1_1star_1_1document_1_1XShapeEventListener.html#a618b1ed8187696c9e531c901b4c4a53b',1,'com::sun::star::document::XShapeEventListener']]],
  ['notifystoragechange_30',['notifyStorageChange',['../interfacecom_1_1sun_1_1star_1_1document_1_1XStorageChangeListener.html#ad006e8314fef6d21ab39d07411ebe907',1,'com::sun::star::document::XStorageChangeListener']]],
  ['notifytermination_31',['notifyTermination',['../interfacecom_1_1sun_1_1star_1_1frame_1_1XTerminateListener.html#a0706eb591601f0ab905dbc09e6b6699e',1,'com::sun::star::frame::XTerminateListener']]],
  ['notifyvbascriptevent_32',['notifyVBAScriptEvent',['../interfacecom_1_1sun_1_1star_1_1script_1_1vba_1_1XVBAScriptListener.html#a8102ad1483741fd69e1b7c2616a588f4',1,'com::sun::star::script::vba::XVBAScriptListener']]],
  ['nullplusnonnullisnull_33',['nullPlusNonNullIsNull',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a0bd08acbae007160cb7b545a63f26c10',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedatend_34',['nullsAreSortedAtEnd',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a949529017da964d23a9bbbd5f307523b',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedatstart_35',['nullsAreSortedAtStart',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#afe6224d12d287d561b6408fa1d8018fc',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedhigh_36',['nullsAreSortedHigh',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#aa29ce4154bfda07935c24b7a72e710dc',1,'com::sun::star::sdbc::XDatabaseMetaData']]],
  ['nullsaresortedlow_37',['nullsAreSortedLow',['../interfacecom_1_1sun_1_1star_1_1sdbc_1_1XDatabaseMetaData.html#a37fac2ea5bc098e2770c369a2b11e9cc',1,'com::sun::star::sdbc::XDatabaseMetaData']]]
];
